==> alibabacloud_btripopen20220520-1.0.57.tar.gz: alibabacloud_btripopen20220520-1.0.57/ChangeLog.md <==
2023-03-20 Version: 1.0.56
- Update.

2023-03-20 Version: 1.0.55
- Update.

2023-03-15 Version: 1.0.54
- Update.

2023-03-15 Version: 1.0.52
- Update.

2023-03-06 Version: 1.0.51
- Add a jump action type to the reimbursement list page.
- Add subCorpId field optional.

2023-03-02 Version: 1.0.50
- Add a jump action type to the reimbursement list page.
- Add subCorpId field optional.

2023-02-22 Version: 1.0.49
- Add new interface.

2023-02-22 Version: 1.0.48
- Add new interface.

2023-02-21 Version: 1.0.47
- Update.

2023-02-21 Version: 1.0.46
- Update.

2023-02-20 Version: 1.0.45
- Update.

2023-02-17 Version: 1.0.44
- Update.

2023-02-15 Version: 1.0.42
- Add Other.

2023-02-10 Version: 1.0.41
- Add Other.

2023-02-10 Version: 1.0.40
- Add Other.

2023-01-29 Version: 1.0.39
- Build again.

2023-01-29 Version: 1.0.38
- Update flight search list.

2023-01-18 Version: 1.0.37
- Add flight search list.

2023-01-16 Version: 1.0.36
- Add dtb.

2022-12-26 Version: 1.0.35
- Add get CorpLink.

2022-12-16 Version: 1.0.34
- Add result param leave_status.

2022-12-15 Version: 1.0.33
- ApplyAdd and ApplyModify.

2022-12-07 Version: 1.0.32
- estimated price filed mod

2022-12-02 Version: 1.0.31
- TrainOrderQuery Add Field.

2022-11-30 Version: 1.0.30
- City info.

2022-11-30 Version: 1.0.29
- Estimated price access to pop platform.

2022-11-28 Version: 1.0.28
- Update Hotel and Car Order detail.

2022-11-03 Version: 1.0.27
- Update CorpToken,allow sk.

2022-10-21 Version: 1.0.26
- Update map struct.

2022-10-21 Version: 1.0.25
- Update code String.

2022-10-17 Version: 1.0.24
- Update CarBillSettlementQuery.

2022-10-14 Version: 1.0.23
- Update module.

2022-10-13 Version: 1.0.22
- Update thirdpart_depart_id.

2022-10-10 Version: 1.0.21
- Update requestId.

2022-10-09 Version: 1.0.19
- Update requestId.

2022-10-09 Version: 1.0.17
- Update Syn Person.

2022-09-29 Version: 1.0.16
- Update Code and Message.

2022-09-28 Version: 1.0.15
- Update Code and Message.

2022-09-19 Version: 1.0.14
- Update Train Order.

2022-09-15 Version: 1.0.13
- Update Code and Message.

2022-09-15 Version: 1.0.12
- Update AccessToken AK.

2022-09-06 Version: 1.0.11
- Update ApplyAdd and ApplyModify.

2022-09-01 Version: 1.0.10
- Add some api.

2022-08-26 Version: 1.0.9
- Add some api.

2022-08-26 Version: 1.0.8
- Add Header Parameter.

2022-08-23 Version: 1.0.7
- Change some input parameter type.

2022-08-22 Version: 1.0.6
- Change the input parameter type.

2022-08-17 Version: 1.0.5
- Change the input parameter type.

2022-08-15 Version: 1.0.4
- Change the input parameter type.

2022-08-09 Version: 1.0.3
- Update params.

2022-07-27 Version: 1.0.2
- Init version.

2022-07-26 Version: 1.0.1
- Test3.

2022-07-18 Version: 1.0.0
- Test2.

==> alibabacloud_btripopen20220520-1.0.68.tar.gz: alibabacloud_btripopen20220520-1.0.68/ChangeLog.md <==
2023-05-09 Version: 1.0.67
- Update.

2023-05-08 Version: 1.0.66
- Update.

2023-05-05 Version: 1.0.65
- Update.

2023-05-05 Version: 1.0.64
- Update.

2023-04-28 Version: 1.0.63
- Update.

2023-04-27 Version: 1.0.62
- Update.

2023-04-23 Version: 1.0.61
- Update.

2023-04-19 Version: 1.0.60
- Update.

2023-04-18 Version: 1.0.59
- Update.

2023-04-14 Version: 1.0.58
- Update.

2023-04-07 Version: 1.0.57
- Update.

2023-03-20 Version: 1.0.56
- Update.

2023-03-20 Version: 1.0.55
- Update.

2023-03-15 Version: 1.0.54
- Update.

2023-03-15 Version: 1.0.52
- Update.

2023-03-06 Version: 1.0.51
- Add a jump action type to the reimbursement list page.
- Add subCorpId field optional.

2023-03-02 Version: 1.0.50
- Add a jump action type to the reimbursement list page.
- Add subCorpId field optional.

2023-02-22 Version: 1.0.49
- Add new interface.

2023-02-22 Version: 1.0.48
- Add new interface.

2023-02-21 Version: 1.0.47
- Update.

2023-02-21 Version: 1.0.46
- Update.

2023-02-20 Version: 1.0.45
- Update.

2023-02-17 Version: 1.0.44
- Update.

2023-02-15 Version: 1.0.42
- Add Other.

2023-02-10 Version: 1.0.41
- Add Other.

2023-02-10 Version: 1.0.40
- Add Other.

2023-01-29 Version: 1.0.39
- Build again.

2023-01-29 Version: 1.0.38
- Update flight search list.

2023-01-18 Version: 1.0.37
- Add flight search list.

2023-01-16 Version: 1.0.36
- Add dtb.

2022-12-26 Version: 1.0.35
- Add get CorpLink.

2022-12-16 Version: 1.0.34
- Add result param leave_status.

2022-12-15 Version: 1.0.33
- ApplyAdd and ApplyModify.

2022-12-07 Version: 1.0.32
- estimated price filed mod

2022-12-02 Version: 1.0.31
- TrainOrderQuery Add Field.

2022-11-30 Version: 1.0.30
- City info.

2022-11-30 Version: 1.0.29
- Estimated price access to pop platform.

2022-11-28 Version: 1.0.28
- Update Hotel and Car Order detail.

2022-11-03 Version: 1.0.27
- Update CorpToken,allow sk.

2022-10-21 Version: 1.0.26
- Update map struct.

2022-10-21 Version: 1.0.25
- Update code String.

2022-10-17 Version: 1.0.24
- Update CarBillSettlementQuery.

2022-10-14 Version: 1.0.23
- Update module.

2022-10-13 Version: 1.0.22
- Update thirdpart_depart_id.

2022-10-10 Version: 1.0.21
- Update requestId.

2022-10-09 Version: 1.0.19
- Update requestId.

2022-10-09 Version: 1.0.17
- Update Syn Person.

2022-09-29 Version: 1.0.16
- Update Code and Message.

2022-09-28 Version: 1.0.15
- Update Code and Message.

2022-09-19 Version: 1.0.14
- Update Train Order.

2022-09-15 Version: 1.0.13
- Update Code and Message.

2022-09-15 Version: 1.0.12
- Update AccessToken AK.

2022-09-06 Version: 1.0.11
- Update ApplyAdd and ApplyModify.

2022-09-01 Version: 1.0.10
- Add some api.

2022-08-26 Version: 1.0.9
- Add some api.

2022-08-26 Version: 1.0.8
- Add Header Parameter.

2022-08-23 Version: 1.0.7
- Change some input parameter type.

2022-08-22 Version: 1.0.6
- Change the input parameter type.

2022-08-17 Version: 1.0.5
- Change the input parameter type.

2022-08-15 Version: 1.0.4
- Change the input parameter type.

2022-08-09 Version: 1.0.3
- Update params.

2022-07-27 Version: 1.0.2
- Init version.

2022-07-26 Version: 1.0.1
- Test3.

2022-07-18 Version: 1.0.0
- Test2.
